@@ -1,7 +1,7 @@
 from defusedxml.ElementTree import XML
 
 from myprss import logger
-from myprss.utils import parse_rfc822_date
+from myprss.utils import parse_from_rfc822_to_date
 
 
 def parse_rss_content(data):
@@ -21,7 +21,7 @@ def parse_rss_content(data):
     for item in channel.findall("item"):
         data["items"].append(
             {
-                "date": parse_rfc822_date(item.find("pubDate").text),
+                "date": parse_from_rfc822_to_date(item.find("pubDate").text),
                 "title": item.find("title").text,
                 "url": item.find("link").text,
                 "description": item.find("description").text,
